@@ -122,6 +122,12 @@ from .usecases.gas_leak_detection import GasLeakDetectionConfig, GasLeakDetectio
 from .usecases.license_plate_monitoring import LicensePlateMonitorConfig,LicensePlateMonitorUseCase
 from .usecases.dwell_detection import DwellConfig,DwellUseCase
 from .usecases.age_gender_detection import AgeGenderConfig, AgeGenderUseCase
+from .usecases.people_tracking import PeopleTrackingConfig,PeopleTrackingUseCase
+from .usecases.wildlife_monitoring import WildLifeMonitoringConfig, WildLifeMonitoringUseCase
+from .usecases.pcb_defect_detection import PCBDefectConfig, PCBDefectUseCase
+from .usecases.underground_pipeline_defect_detection import UndergroundPipelineDefectConfig,UndergroundPipelineDefectUseCase
+from .usecases.suspicious_activity_detection import SusActivityConfig, SusActivityUseCase
+from .usecases.natural_disaster import NaturalDisasterConfig, NaturalDisasterUseCase
 
 #Put all IMAGE based usecases here
 from .usecases.blood_cancer_detection_img import BloodCancerDetectionConfig, BloodCancerDetectionUseCase
@@ -130,6 +136,9 @@ from .usecases.plaque_segmentation_img import PlaqueSegmentationConfig, PlaqueSe
 from .usecases.smoker_detection import SmokerDetectionUseCase, SmokerDetectionConfig
 from .usecases.Histopathological_Cancer_Detection_img import HistopathologicalCancerDetectionConfig, HistopathologicalCancerDetectionUseCase
 
+# Face recognition with embeddings
+from .face_reg.face_recognition import FaceRecognitionEmbeddingUseCase, FaceRecognitionEmbeddingConfig
+
 # Use case implementations
 from .usecases import (
     PeopleCountingUseCase,
@@ -187,8 +196,13 @@ from .usecases import (
     LicensePlateMonitorUseCase,
     DwellUseCase,
     AgeGenderUseCase,
-
+    WildLifeMonitoringUseCase,
+    PCBDefectUseCase,
     HumanActivityUseCase,
+    UndergroundPipelineDefectUseCase,
+
+    SusActivityUseCase,
+    NaturalDisasterUseCase,
 
     #Put all IMAGE based usecases here
     BloodCancerDetectionUseCase,
@@ -263,7 +277,15 @@ _gas_leak_detection = GasLeakDetectionUseCase()
 _license_plate_monitor = LicensePlateMonitorUseCase()
 _dwell = DwellUseCase()
 _age_gender_detection = AgeGenderUseCase()
+_people_tracking = PeopleTrackingUseCase()
+_wildlife_monitoring = WildLifeMonitoringUseCase()
+_pcb_defect_detection = PCBDefectUseCase()
+_underground_pipeline_defect = UndergroundPipelineDefectUseCase()
+_suspicious_activity_detection = SusActivityUseCase()
+_natural_disaster = NaturalDisasterUseCase()
 
+# Face recognition with embeddings
+_face_recognition = FaceRecognitionEmbeddingUseCase()
 
 #Put all IMAGE based usecases here
 _blood_cancer_detection = BloodCancerDetectionUseCase()
@@ -336,7 +358,14 @@ registry.register_use_case(_human_activity_recognition.category, _human_activity
 registry.register_use_case(_gas_leak_detection.category, _gas_leak_detection.name, GasLeakDetectionUseCase)
 registry.register_use_case(_license_plate_monitor.category, _license_plate_monitor.name, LicensePlateMonitorUseCase)
 registry.register_use_case(_dwell.category, _dwell.name, DwellUseCase)
+registry.register_use_case(_face_recognition.category, _face_recognition.name, FaceRecognitionEmbeddingUseCase)
 registry.register_use_case(_age_gender_detection.category, _age_gender_detection.name, AgeDetectionUseCase)
+registry.register_use_case(_people_tracking.category, _people_tracking.name, PeopleTrackingUseCase)
+registry.register_use_case(_wildlife_monitoring.category, _wildlife_monitoring.name, WildLifeMonitoringUseCase)
+registry.register_use_case(_pcb_defect_detection.category, _pcb_defect_detection.name, PCBDefectUseCase)
+registry.register_use_case(_underground_pipeline_defect.category, _underground_pipeline_defect.name, UndergroundPipelineDefectUseCase)
+registry.register_use_case(_suspicious_activity_detection.category, _suspicious_activity_detection.name, SusActivityUseCase)
+registry.register_use_case(_natural_disaster.category, _natural_disaster.name, NaturalDisasterUseCase)
 
 #Put all IMAGE based usecases here
 registry.register_use_case(_blood_cancer_detection.category, _blood_cancer_detection.name, BloodCancerDetectionUseCase)
@@ -532,9 +561,15 @@ __all__ = [
     'AbandonedObjectConfig',
     'GasLeakDetectionConfig',
     'HumanActivityConfig',
+    'FaceRecognitionEmbeddingConfig',
     'LicensePlateMonitorConfig',
     'DwellConfig',
     'AgeGenderConfig',
+    'WildLifeMonitoringConfig',
+    'PCBDefectConfig',
+    'UndergroundPipelineDefectConfig',
+    'SusActivityConfig',
+    'NaturalDisasterConfig',
 
     #Put all IMAGE based usecase CONFIGS here
     'BloodCancerDetectionConfig',
@@ -599,9 +634,15 @@ __all__ = [
     'AbandonedObjectDetectionUseCase',
     'HumanActivityUseCase',
     'GasLeakDetectionUseCase',
+    'FaceRecognitionEmbeddingUseCase',
     'LicensePlateMonitorUseCase',
     'DwellUseCase',
     'AgeGenderUseCase',
+    'WildLifeMonitoringUseCase',
+    'PCBDefectUseCase',
+    'UndergroundPipelineDefectUseCase',
+    'SusActivityUseCase',
+    'NaturalDisasterUseCase',
 
     #Put all IMAGE based usecases here
     'BloodCancerDetectionUseCase',
