@@ -25,8 +25,9 @@ from ..core.config import BaseConfig, AlertConfig
 class AbandonedObjectConfig(BaseConfig):
     """Configuration for abandoned object detection use case."""
     enable_smoothing: bool = True
-    centroid_threshold: float = 15.0
+    centroid_threshold: float = 30.0
     proximity_threshold: float = 50.0  # New: Distance threshold for person proximity
+    proximity_hysteresis_frames: int = 5  # New: Frames required for proximity reset
     smoothing_algorithm: str = "observability"
     smoothing_window_size: int = 20
     smoothing_cooldown_frames: int = 5
@@ -34,7 +35,7 @@ class AbandonedObjectConfig(BaseConfig):
     confidence_threshold: float = 0.4
     stationary_threshold_frames: int = 30
     usecase_categories: List[str] = field(default_factory=lambda: ['backpack', 'handbag', 'suitcase'])
-    target_categories: List[str] = field(default_factory=lambda: ['backpack', 'handbag', 'suitcase'])
+    target_categories: List[str] = field(default_factory=lambda: ['handbag'])
     alert_config: Optional[AlertConfig] = None
     zone_config: Optional[Dict[str, Dict[str, List[List[float]]]]] = None
     index_to_category: Optional[Dict[int, str]] = field(
@@ -51,7 +52,7 @@ class AbandonedObjectDetectionUseCase(BaseProcessor):
         self.category = "security"
         self.CASE_TYPE: Optional[str] = 'abandoned_object_detection'
         self.CASE_VERSION: Optional[str] = '1.0'
-        self.target_categories = ['backpack', 'handbag', 'suitcase']
+        self.target_categories = ['handbag']
         self.smoothing_tracker = None
         self.tracker = None
         self._total_frame_counter = 0
@@ -191,18 +192,14 @@ class AbandonedObjectDetectionUseCase(BaseProcessor):
                         is_near_person = True
                         break
 
-            if is_near_person:
-                if track_id in self._stationary_tracks:
-                    del self._stationary_tracks[track_id]
-                continue
-
             if track_id not in self._stationary_tracks:
                 self._stationary_tracks[track_id] = {
                     'centroid': centroid,
                     'frame_count': 1,
                     'start_time': current_time,
                     'bbox': bbox,
-                    'in_zone': in_zone
+                    'in_zone': in_zone,
+                    'proximal_frames': 0
                 }
                 track_info = self._stationary_tracks[track_id]
                 if track_info['frame_count'] >= config.stationary_threshold_frames and in_zone:
@@ -211,6 +208,15 @@ class AbandonedObjectDetectionUseCase(BaseProcessor):
                     self.logger.info(f"Marked as abandoned_object: {det}")
             else:
                 track_info = self._stationary_tracks[track_id]
+
+                if is_near_person:
+                    track_info['proximal_frames'] = track_info.get('proximal_frames', 0) + 1
+                    if track_info['proximal_frames'] >= config.proximity_hysteresis_frames:
+                        track_info['frame_count'] = 1
+                        track_info['start_time'] = current_time
+                    continue
+
+                track_info['proximal_frames'] = 0
                 prev_centroid = track_info['centroid']
                 track_info['frame_count'] += 1
                 track_info['bbox'] = bbox
